# -*- coding: utf-8 -*-
"""
Created on Wed Mar  6 15:38:30 2019

@author: Kristoffer Prestvold
"""

import pandas as pd
import matplotlib.pyplot as plt
import numpy as np
#%%
plt.close('all')
#%%
df=pd.read_csv('radataEN0305.csv')

radTur=df['radTur'].values
n=len(radTur)
radRetur=df['radRetur'].values
radFlow=df['radFlow'].values
dato=df['Dato'].values
utetemp=df['utetemp'].values
startDato=dato[0]
sluttDato=dato[n-1]
deltaT=radTur-radRetur


Cp=4.2

#%%
#Effekter og varighetskurve
radEffekt=radFlow*Cp*deltaT
radVarigEffekt=-np.sort(-radEffekt)

dimEffekt=np.ones((n,1))*455
plt.plot(range(1,n+1),dimEffekt,'tab:orange',label='Dimmensjonerende effektbehov')

plt.plot(range(1,n+1),radVarigEffekt,label='Varighetskurve')
plt.fill_between(range(1,n+1),radVarigEffekt)
plt.title('Varighetskurve radiatorkrets',fontweight='bold')
plt.xticks([0,3000,6000,9000],[0,500,1000,1500])
plt.xlabel('Timer')
plt.ylabel('Effekt [kW]')


plt.legend(loc=(0.44,0.8))

Effekt_maks=np.amax(radEffekt)
Effekt_min=np.amin(radEffekt)
print('Minimum og maksimum radiatoreffekt ligger på henholdsvis %dkW og %dkW' % (Effekt_min,Effekt_maks))
print('Gjennomsnittlig radiatoreffekt ligger på %dkW' % np.mean(radEffekt))
#%%

#Tur- og returtemperaturer
plt.figure(2)
plt.plot(range(1,n+1),radTur,'r',label='Tur')
plt.plot(range(1,n+1),radRetur,'b', label='Retur')
plt.title('Tur- og returtemperaturer radiatorkrets', fontweight='bold' )
plt.ylabel('Temperatur [\xb0C]')
plt.xticks([864,5328,9792],['1. jan.','1. feb.','1. mar.'])
plt.legend()
print('Minimum og maksimum turtemperatur ligger på henholdsvis %.2fC og %.2fC' % (np.amin(radTur),np.amax(radTur)))
print('Minimum og maksimum returtemperatur ligger på henholdsvis %.2fC og %.2fC' % (np.amin(radRetur),np.amax(radRetur)))
print('Gjennomsnittlig DeltaT ligger på %.2f K' % (np.mean(deltaT)))

#%%
#Utetemperatur
plt.figure(3)
plt.plot(range(1,n+1),utetemp)
plt.title('Utetemperaturer fra %s til %s' % (startDato,sluttDato), fontweight='bold' )
plt.ylabel('Temperatur [\xb0C]')
print('Minimum og maksimum utetemperatur ligger på henholdsvis %.2f\xb0C og %.2f\xb0C' % (np.amin(utetemp),np.amax(utetemp)))
print('Gjennomsnittlig utetemperatur ligger på %.2f\xb0C' % (np.mean(utetemp)))

#%%
#Sammenheng mellom utetemperatur og turtemperatur
ua=np.round(utetemp,1) #Utetemperatur avrundes til 1 desimal
max_ua=np.amax(ua)
min_ua=np.amin(ua)
u_stigende=np.round(np.arange(min_ua,max_ua+0.1,0.1),1)

tabell=np.ones((len(utetemp),4))
teller=0

for temp in u_stigende:
    indeks=np.argwhere(ua==temp)
    
    
    if len(indeks)==0:
        continue
        
    for i in indeks:
        tabell[teller,0]=temp
        tabell[teller,1]=radTur[i]
        tabell[teller,2]=radRetur[i]
        tabell[teller,3]=radEffekt[i]
        teller +=1
#Reguleringskurve
ute=[-20,-10,-5,3,10,20]
regtemp=[59,56,53,45,40,33]

plt.figure(4)
plt.scatter(tabell[:,0],tabell[:,1],c='r',label='Tur',s=1.5)
plt.scatter(tabell[:,0],tabell[:,2],c='b', label='Retur',s=1.5)
plt.plot(ute,regtemp,'k',label='Reguleringskurve', linewidth=0.7)
plt.legend()
plt.title('Sammenheng mellom utetemperatur og tur- og returtemperatur',fontweight='bold')
plt.xlabel('Utetemperatur [\xb0C]')
plt.ylabel('Temperatur [\xb0C]')

plt.figure(5)
plt.scatter(tabell[:,0],tabell[:,3])
plt.title('Sammenheng mellom utetemperatur og effektbehov',fontweight='bold')


#%%
'''
Verdier hentet fra ventilasjonskrets
'''
ventTur=df['ventTur'].values
ventRetur=df['ventRetur'].values
ventFlow=df['ventFlow'].values

deltaTV=ventTur-ventRetur
#Effekter og varighetskurve
plt.figure(6)
ventEffekt=ventFlow*Cp*deltaTV
varigEffekt=-np.sort(-ventEffekt)
plt.plot(range(1,n+1),varigEffekt,label='Varighetskurve')
plt.fill_between(range(1,n+1),varigEffekt)
plt.title('Varighetskurve ventilasjonskrets',fontweight='bold')
plt.ylabel('Effekt [kW]')

#Dimensjonerende effektbehov
dimEff=np.ones((n,1))*3200
plt.plot(range(1,n+1),dimEff, label='Dimensjonerende effektbehov')
plt.legend(loc=(0.45,0.78))

Effekt_maks=np.amax(ventEffekt)
Effekt_min=np.amin(ventEffekt)
print('Minimum og maksimum radiatoreffekt ligger på henholdsvis %dkW og %dkW' % (Effekt_min,Effekt_maks))
#%%

#Tur- og returtemperaturer
plt.figure(7)
plt.plot(range(1,n+1),ventTur,'r',label='Tur')
plt.plot(range(1,n+1),ventRetur,'b', label='Retur')
#plt.title('Tur og returtemperaturer ventilasjon fra %s til %s' % (startDato,sluttDato), fontweight='bold' )
plt.title('Tur- og returtemperatur ventilasjonskrets',fontweight='bold')
plt.ylabel('Temperatur [\xb0C]')
plt.xticks([864,5328,9792],['1. jan.','1. feb.','1. mar.'])

plt.legend()
print('Minimum og maksimum ventilasjon turtemperatur ligger på henholdsvis %.2fC og %.2fC' % (np.amin(radTur),np.amax(radTur)))
print('Minimum og maksimum ventilasjon returtemperatur ligger på henholdsvis %.2fC og %.2fC' % (np.amin(radRetur),np.amax(radRetur)))
print('Gjennomsnittlig DeltaT ligger på %.2f K' % (np.mean(deltaTV)))


#%%
#Sammenheng mellom utetemperatur og turtemperatur
ua=np.round(utetemp,1) #Utetemperatur avrundes til 1 desimal
max_ua=np.amax(ua)
min_ua=np.amin(ua)
u_stigende=np.round(np.arange(min_ua,max_ua+0.1,0.1),1)

tabell=np.ones((len(utetemp),4))
teller=0

for temp in u_stigende:
    indeks=np.argwhere(ua==temp)
    
    
    if len(indeks)==0:
        continue
        
    for i in indeks:
        tabell[teller,0]=temp
        tabell[teller,1]=ventTur[i]
        tabell[teller,2]=ventRetur[i]
        tabell[teller,3]=ventEffekt[i]
        teller +=1
#Reguleringskurve
ute=[-20,-10,-5,3,10,20]
regtemp=[50,50,46,41,38,35]
regTidlig=[50,48,43,38]
uteTidlig=[-10,-5,3,10]

plt.figure(8)
plt.scatter(tabell[:,0],tabell[:,1],c='r',label='Tur',s=1.5)
plt.scatter(tabell[:,0],tabell[:,2],c='b', label='Retur',s=1.5)
plt.plot(ute,regtemp,'k',label='Reguleringskurve',linewidth=0.7)
plt.plot(uteTidlig,regTidlig, 'k', label='Tigligere reguleringskurvve', linestyle='dashed',linewidth=1)
plt.axis([-20,20,20,58])
plt.legend()
plt.title('Sammenheng mellom utetemperatur og tur- og returtemperatur ventilasjon',fontweight='bold')
plt.xlabel('Utetemperatur [\xb0C]')
plt.ylabel('Temperatur [\xb0C]')

plt.figure(9)
plt.scatter(tabell[:,0],tabell[:,3])
plt.title('Sammenheng mellom utetemperatur og effektbehov ventilasjon',fontweight='bold')
        


